'use strict';

const _ = require('lodash');
const path = require('path');
const vueLoaderConfig = require('./vue-loader.conf');
const MpvuePlugin = require('webpack-mpvue-asset-plugin');
const glob = require('glob');
const CopyWebpackPlugin = require('copy-webpack-plugin');
const relative = require('relative');

function resolve(dir) {
  return path.join(process.cwd(), dir);
}
function getEntry(rootSrc) {
  let map = {};
  glob.sync(rootSrc + '/pages/**/main.js').forEach(file => {
    let key = relative(rootSrc, file).replace('.js', '');
    map[key] = file;
  });
  return map;
}
const appEntry = {
  app: resolve('./src/main.js'),
};
const pagesEntry = getEntry(resolve('./src'), 'pages/**/main.js');
const entry = Object.assign({}, appEntry, pagesEntry);

function createConfig(wefe) {
  let config = {};

  // 入口
  config.entry = entry;
  config.target = require('mpvue-webpack-target');
  module: {
    rules: utils.styleLoaders({
      extract: true,
    });

  config.output = {
    path: resolve('dist'),
    filename: '[name].js',
    chunkFilename: '[id].js',
  },

  config.module = {
    rules: {
      mpvue: {
        test: /\.vue$/,
        use: {
          'mpvue-loader': {
            loader: 'mpvue-loader',
            options: vueLoaderConfig,
          },
        },
      },
    },
  };

  // resolve
  config.resolve = {
    extensions: ['.js', '.vue', '.json'],
    alias: {
      'vue': 'mpvue',
    },
    symlinks: false,
    aliasFields: ['mpvue', 'weapp', 'browser'],
    mainFields: ['browser', 'module', 'main'],
  };

  // 插件
  config.plugin = _.extend(config.plugin, {
    'webpack_CopyWebpackPlugin': {
      plugin: CopyWebpackPlugin,
      args: [{
        from: '**/*.json',
        to: '',
        context: 'src/',
      }],
    },
    'webpack_MpvuePlugin': {
      plugin: MpvuePlugin,
    },
  });

  return config;
}

module.exports = createConfig;